@@ -48,6 +48,9 @@ bool PTBatcherGUI::OnInit()
     SetAppName(wxT("hugin"));
 
 #if defined __WXMSW__
+#if defined _MSC_VER && defined Hugin_shared
+    setlocale(LC_NUMERIC, "");
+#endif
     int localeID = wxConfigBase::Get()->Read(wxT("language"), (long) wxLANGUAGE_DEFAULT);
     m_locale.Init(localeID);
     // initialize help provider
@@ -80,16 +83,6 @@ bool PTBatcherGUI::OnInit()
             return false;
         }
 
-        wxString thePath = MacGetPathToBundledResourceFile(CFSTR("locale"));
-        if(thePath != wxT(""))
-        {
-            m_locale.AddCatalogLookupPathPrefix(thePath);
-        }
-        else
-        {
-            wxMessageBox(_("Translations not found in bundle"), _("Fatal Error"));
-            return false;
-        }
     }
 #else
     // add the locale directory specified during configure
@@ -217,30 +210,29 @@ bool PTBatcherGUI::OnInit()
             return false;
         }
     };
-    //m_frame->SetLocaleAndXRC(&m_locale,m_xrcPrefix);
-    //projectsRunning=0;
-    unsigned int count = 0;
-    if(parser.Found(wxT("a")))
+
+    size_t count = 0;
+    if (parser.Found(wxT("a")))
     {
         //added assistant files
-        while(parser.GetParamCount()>count)
+        while (parser.GetParamCount() > count)
         {
             wxString param = parser.GetParam(count);
             count++;
             wxFileName name(param);
             name.MakeAbsolute();
-            if(name.FileExists())
+            if (name.FileExists())
             {
                 //only add existing pto files
-                if(name.GetExt().CmpNoCase(wxT("pto"))==0)
+                if (name.GetExt().CmpNoCase(wxT("pto")) == 0)
                 {
-                    if(IsFirstInstance)
+                    if (IsFirstInstance)
                     {
-                        m_frame->AddToList(name.GetFullPath(),Project::DETECTING);
+                        m_frame->AddToList(name.GetFullPath(), Project::DETECTING);
                     }
                     else
                     {
-                        conn->Request(wxT("D ")+name.GetFullPath());
+                        conn->Request(wxT("D ") + name.GetFullPath());
                     };
                 };
             };
@@ -250,21 +242,21 @@ bool PTBatcherGUI::OnInit()
     {
         bool projectSpecified = false;
         //we collect all parameters - all project files <and their output prefixes>
-        while(parser.GetParamCount()>count)
+        while (parser.GetParamCount() > count)
         {
             wxString param = parser.GetParam(count);
             count++;
-            if(!projectSpecified)	//next parameter must be new script file
+            if (!projectSpecified)	//next parameter must be new script file
             {
                 wxFileName name(param);
                 name.MakeAbsolute();
-                if(IsFirstInstance)
+                if (IsFirstInstance)
                 {
                     m_frame->AddToList(name.GetFullPath());
                 }
                 else
                 {
-                    conn->Request(wxT("A ")+name.GetFullPath());
+                    conn->Request(wxT("A ") + name.GetFullPath());
                 }
                 projectSpecified = true;
             }
@@ -272,15 +264,15 @@ bool PTBatcherGUI::OnInit()
             {
                 wxFileName fn(param);
                 fn.MakeAbsolute();
-                if(!fn.HasExt())	//if there is no extension we have a prefix
+                if (!fn.HasExt())	//if there is no extension we have a prefix
                 {
-                    if(IsFirstInstance)
+                    if (IsFirstInstance)
                     {
-                        m_frame->ChangePrefix(-1,fn.GetFullPath());
+                        m_frame->ChangePrefix(-1, fn.GetFullPath());
                     }
                     else
                     {
-                        conn->Request(wxT("P ")+fn.GetFullPath());
+                        conn->Request(wxT("P ") + fn.GetFullPath());
                     }
                     projectSpecified = false;
                 }
@@ -288,50 +280,39 @@ bool PTBatcherGUI::OnInit()
                 {
                     wxString ext = fn.GetExt();
                     //we may still have a prefix, but with added image extension
-                    if (ext.CmpNoCase(wxT("jpg")) == 0 || ext.CmpNoCase(wxT("jpeg")) == 0||
-                            ext.CmpNoCase(wxT("tif")) == 0|| ext.CmpNoCase(wxT("tiff")) == 0 ||
-                            ext.CmpNoCase(wxT("png")) == 0 || ext.CmpNoCase(wxT("exr")) == 0 ||
-                            ext.CmpNoCase(wxT("pnm")) == 0 || ext.CmpNoCase(wxT("hdr")) == 0)
+                    if (ext.CmpNoCase(wxT("jpg")) == 0 || ext.CmpNoCase(wxT("jpeg")) == 0 ||
+                        ext.CmpNoCase(wxT("tif")) == 0 || ext.CmpNoCase(wxT("tiff")) == 0 ||
+                        ext.CmpNoCase(wxT("png")) == 0 || ext.CmpNoCase(wxT("exr")) == 0 ||
+                        ext.CmpNoCase(wxT("pnm")) == 0 || ext.CmpNoCase(wxT("hdr")) == 0)
                     {
                         //extension will be removed before stitch, so there is no need to do it now
-                        if(IsFirstInstance)
+                        if (IsFirstInstance)
                         {
-                            m_frame->ChangePrefix(-1,fn.GetFullPath());
+                            m_frame->ChangePrefix(-1, fn.GetFullPath());
                         }
                         else
                         {
-                            conn->Request(wxT("P ")+fn.GetFullPath());
+                            conn->Request(wxT("P ") + fn.GetFullPath());
                         }
                         projectSpecified = false;
                     }
                     else //if parameter has a different extension we presume it is a new script file
                     {
                         //we add the new project
-                        if(IsFirstInstance)
+                        if (IsFirstInstance)
                         {
                             m_frame->AddToList(fn.GetFullPath());
                         }
                         else
                         {
-                            conn->Request(wxT("A ")+fn.GetFullPath());
+                            conn->Request(wxT("A ") + fn.GetFullPath());
                         }
                         projectSpecified = true;
                     }
                 } //else of if(!fn.HasExt())
             }
         }
-    }
-
-#if 0 //ifdef __WXMAC__
-    // see PTBatcherGUI::MacOpenFile for explanation
-    m_macFileNameToOpenOnStart = wxT("");
-    wxYield();
-    if(m_macFileNameToOpenOnStart != wxT(""))
-    {
-        wxFileName fn(m_macFileNameToOpenOnStart);
-        m_frame->AddToList(fn.GetFullPath());
-    }
-#endif
+    };
 
     if(IsFirstInstance)
     {
@@ -392,6 +373,20 @@ bool PTBatcherGUI::OnInit()
     {
         m_frame->RunBatch();
     }
+#ifdef __WXMAC__
+    // if there are command line parameters they are handled all by the code above
+    // but wxMac calls also MacOpenFiles after OnInit with the command line
+    // parameters again, so the files get added twice. To prevent this we
+    // reset the internal file list for MacOpenFiles here
+    // but we need to process the files when PTBatcherGUI is called from finder
+    // with an open files AppleEvent, in this case the argv is empty (except argc[0])
+    // and we don't want to skip the MacOpenFile function
+    if (argc > 1)
+    {
+        wxArrayString emptyFiles;
+        OSXStoreOpenFiles(emptyFiles);
+    };
+#endif
     return true;
 }
 
@@ -437,24 +432,18 @@ void PTBatcherGUI::OnKeyDown(wxKeyEvent& event)
 
 }
 
-#if 0 //ifdef __WXMAC__
-// wx calls this method when the app gets "Open file" AppleEvent
-// this does not work with wxWidgets 2.9.3, Cocoa variant. The project is added twice.
-// From the doc it is recommended to react only on MacOpenFile
-// So we should  to skip to code concerning command line parsing in OnInit, and parse it here
-// But this does not work. MacOpenFile is not called when PTBatcherGUI is already running
-// So for the moment I leave the code in OnInit also for Mac
-void PTBatcherGUI::MacOpenFile(const wxString& fileName)
+#ifdef __WXMAC__
+// wx calls this method when the app gets "Open files" AppleEvent
+void PTBatcherGUI::MacOpenFiles(const wxArrayString &fileNames) 
 {
-    if(!m_frame)
+    if(m_frame)
     {
-        m_macFileNameToOpenOnStart = fileName;
-    }
-    else
-    {
-        wxFileName fn(fileName);
-        m_frame->AddToList(fn.GetFullPath());
-    }
+        for (int i = 0; i < fileNames.GetCount(); ++i)
+        {
+            wxFileName fn(fileNames[i]);
+            m_frame->AddToList(fn.GetFullPath());
+        };
+    };
 }
 #endif
 
