@@ -16,8 +16,8 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -26,7 +26,8 @@
 
 #include <vector>
 #include <functional>
-#include <boost/random/mersenne_twister.hpp>
+#include "hugin_config.h"
+#include <random>
 
 #include <vigra/stdimage.hxx>
 #include <vigra/numerictraits.hxx>
@@ -234,7 +235,7 @@ class InvResponseTransform : public ResponseTransform<VTIn>
         double m_intScale;
         
     private:
-        boost::mt19937 Twister;
+        std::mt19937 Twister;
 };
 
 
@@ -337,8 +338,8 @@ double ResponseTransform<VTIn>::calcVigFactor(hugin_utils::FDiff2D d) const
     } else if (m_VigCorrMode & HuginBase::SrcPanoImage::VIGCORR_FLATFIELD) {
         // TODO: implement flatfield
         if (m_flatfield) {
-            int x = std::min(std::max(hugin_utils::roundi(d.x),0), m_flatfield->width()-1);;
-            int y = std::min(std::max(hugin_utils::roundi(d.y),0), m_flatfield->height()-1);;
+            int x = std::min(std::max(hugin_utils::roundi(d.x),0), static_cast<int>(m_flatfield->width()-1));
+            int y = std::min(std::max(hugin_utils::roundi(d.y),0), static_cast<int>(m_flatfield->height()-1));
             return (*m_flatfield)(x,y);
         } else {
             return 1;
@@ -456,7 +457,7 @@ void InvResponseTransform<VTIn,VTOut>::setOutput(double destExposure, const LUTD
 template <class VTIn, class VTOut>
 double InvResponseTransform<VTIn,VTOut>::dither(const double &v) const
 {
-    boost::mt19937 &mt = const_cast<boost::mt19937 &>(Twister);
+    std::mt19937 &mt = const_cast<std::mt19937 &>(Twister);
     double vFraction = v - floor(v);
     // Only dither values within a certain range of the rounding cutoff point.
     if (vFraction > 0.25 && vFraction <= 0.75) {
