@@ -1,5 +1,5 @@
 
-#if _WINDOWS && defined Hugin_shared 
+#if defined _WIN32 && defined Hugin_shared 
 
 #if defined huginbase_EXPORTS
 #define IMPEX __declspec(dllexport)
@@ -37,7 +37,15 @@
 #define LFIMPEX __declspec(dllimport)
 #endif
 
+#if defined huginlines_EXPORTS
+#define LINESIMPEX __declspec(dllexport)
+#else
+#define LINESIMPEX __declspec(dllimport)
+#endif
+
+#ifdef _MSC_VER
 #pragma warning( disable: 4251 )
+#endif
 
 #else
 #define IMPEX
@@ -46,4 +54,5 @@
 #define LFIMPEX
 #define ICPIMPEX
 #define CELESTEIMPEX
+#define LINESIMPEX
 #endif
